from django.templatetags.static import static

UPLOADER_DEFAULT_THUMBNAIL = static('img/default-thumbnail.png')

UPLOADER_LOGIN_REQUIRED = False

UPLOADER_UPLOAD_DIRECTORY = 'media/attachments/'
